@@ -48,16 +48,13 @@ our %EXPORT_TAGS = (
         ZMQ_XREP
         ZMQ_XSUB
         ZMQ_XPUB
+        ZMQ_ROUTER
+        ZMQ_DEALER
         ZMQ_PULL
         ZMQ_PUSH
         ZMQ_UPSTREAM
         ZMQ_DOWNSTREAM
         ZMQ_BACKLOG
-        ZMQ_FD
-        ZMQ_LINGER
-        ZMQ_EVENTS
-        ZMQ_RECONNECT_IVL
-        ZMQ_TYPE
     ),
 # socket send/recv flags
     qw(
@@ -79,6 +76,12 @@ our %EXPORT_TAGS = (
         ZMQ_SNDBUF
         ZMQ_RCVBUF
         ZMQ_RCVMORE
+        ZMQ_RECONNECT_IVL
+        ZMQ_RECONNECT_IVL_MAX
+        ZMQ_LINGER
+        ZMQ_FD
+        ZMQ_EVENTS
+        ZMQ_TYPE
     ),
 # i/o multiplexing
     qw(
@@ -160,6 +163,10 @@ The exportable constants are:
 
 =item ZMQ_XSUB
 
+=item ZMQ_ROUTER
+
+=item ZMQ_DEALER
+
 =item ZMQ_PULL
 
 =item ZMQ_PUSH
@@ -178,6 +185,8 @@ The exportable constants are:
 
 =item ZMQ_RECONNECT_IVL
 
+=item ZMQ_RECONNECT_IVL_MAX
+
 =item ZMQ_TYPE
 
 =item ZMQ_NOBLOCK
@@ -214,6 +223,8 @@ The exportable constants are:
 
 =item ZMQ_POLLERR
 
+=item ZMQ_RECOVERY_IVL_MSEC
+
 =back
 
 =head2 C<:device> - Device types
@@ -258,8 +269,6 @@ The exportable constants are:
 
 =item ZMQ_VERSION_PATCH
 
-=item ZMQ_RECOVERY_IVL_MSEC
-
 =back
 
 =head2 uncategorized
