@@ -8,6 +8,7 @@ my @modules = qw(
     Module::Install::ReadmeFromPod
     Module::Install::TestTarget
     Module::Install::XSUtil
+    Module::Install::Repository
 );
 
 my @missing;
@@ -30,7 +31,7 @@ modules first:
 EOM
     foreach my $module (@missing) {
         $module =~ s/^inc:://;
-        print "    * $module\n";
+        print STDERR "    * $module\n";
     }
     print STDERR <<EOM;
 and try again.
@@ -38,7 +39,7 @@ and try again.
 While you're at it, install these modules as they are needed to run
 the tests:
 
-* Test::Exception (at least 0.29)
+* Test::Fatal
 * Test::Requires
 * Test::TCP
 * Devel::CheckLib
